.yui3-widget-mask {
    background-color: #000;
    opacity: 0.3;
}
.yui3-panel {
    background-color: #FFF;
    padding: 50px 80px 50px 80px;
    -moz-border-radius: 0 0 6px 6px;
    -webkit-border-radius: 0 0 6px 6px;
    border-radius: 0 0 6px 6px;
    -webkit-box-shadow: 0 0 15px 0 rgba(0,0,0,1);
    box-shadow: 0 0 15px 0 rgba(0,0,0,1);
}
.yui3-widget-hd {
    margin-bottom: 30px;
    font-size: 24px;
}
.yui3-widget-ft {
    margin-top: 50px;
}
.yui3-widget-button-wrapper {
    width: 100%;
}
.yui3-panel .yui3-button {
    float: right;
}
.yui3-panel .yui3-button.link-button {
    float: left;
    padding-left: 0;
    padding-right: 0;
    color: #dd4814;
    border: none;
    background: none;
    -webkit-box-shadow: none;
    box-shadow: none;
    font-size: 13px;
}
