form ul {
    list-style: none;
    margin: 0;
    padding: 0;
}
form li {
    margin-bottom: 16px;
}
form li.form-submit {
    padding: 8px 0 0 0;
    margin-bottom: 0;
    text-align: right;
}
.form-errors,
form .errors,
form .field-error {
    color: #DE3E25;
}
form label {
    display: block;
    margin-bottom: 4px;
}
li ul li label {
    display: inline;
}
input,
select {
    margin: 0;
}
label .required {
    color: #0d4153;
}
form .help {
    display: block;
    color: #aea79f;
}
input[type="checkbox"] {
    margin-right: 3px;
}
textarea,
input[type="password"],
input[type="text"] {
    width: 350px;
    padding: 4px;
    border: 1px solid #999;
    font-size: 13px;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
    background: #FFF;
    overflow: auto;
    white-space: nowrap;
    word-wrap: normal;
}
textarea:focus,
input[type="password"]:focus,
input[type="text"]:focus {
    border-color: #000;
}
li.error textarea,
li.error input[type="password"],
li.error input[type="text"] {
    background-color: #F2CFCE;
}
input[type="text"].disabled {
    background-color: #f2f2f2;
}
input[type="text"]:focus {
    border: 1px solid #999;
}
a.button:hover {
    text-decoration: none;
}
.yui3-button,
.button,
button,
input[type="submit"] {
    padding: 4px 20px;
    color: #fff;
    font-size: 14px;
    text-align: center;
    border: 1px solid #ab370f;
    background-color: #DD4814;
    background-image: linear-gradient(bottom, rgb(199,66,18) 0%, rgb(221,74,20) 100%);
    background-image: -o-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(221,74,20) 100%);
    background-image: -moz-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(221,74,20) 100%);
    background-image: -webkit-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(221,74,20) 100%);
    background-image: -ms-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(221,74,20) 100%);
    -webkit-box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.2);
    box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.2);
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
    border-radius: 6px;
}
.yui3-button:hover,
.button:hover,
button:hover,
input[type="submit"]:hover {
    background-image: linear-gradient(bottom, rgb(199,66,18) 0%, rgb(236,94,43) 100%);
    background-image: -o-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(236,94,43) 100%);
    background-image: -moz-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(236,94,43) 100%);
    background-image: -webkit-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(236,94,43) 100%);
    background-image: -ms-linear-gradient(bottom, rgb(199,66,18) 0%, rgb(236,94,43) 100%);
    text-decoration: none;
}
.yui3-button,
.button {
    display: inline-block;
}

/* Secondary buttons */
.yui3-button.secondary,
.button.secondary,
button.secondary,
input[type="submit"].secondary {
    border-color: #262626;
    background-color: #333;
    background-image: linear-gradient(bottom, rgb(51,51,51) 0%, rgb(77,77,77) 100%);
    background-image: -o-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(77,77,77) 100%);
    background-image: -moz-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(77,77,77) 100%);
    background-image: -webkit-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(77,77,77) 100%);
    background-image: -ms-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(77,77,77) 100%);
    -webkit-box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.1);
    box-shadow: inset 0 1px 0 0 rgba(255, 255, 255, 0.1);
}
.yui3-button.secondary:hover,
.button.secondary:hover,
button.secondary:hover,
input[type="submit"].secondary:hover {
    background-image: linear-gradient(bottom, rgb(51,51,51) 0%, rgb(90,90,90) 100%);
    background-image: -o-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(90,90,90) 100%);
    background-image: -moz-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(90,90,90) 100%);
    background-image: -webkit-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(90,90,90) 100%);
    background-image: -ms-linear-gradient(bottom, rgb(51,51,51) 0%, rgb(90,90,90) 100%);
}
/* Disabled buttons */
.yui3-button.disabled,
.button.disabled,
button.disabled {
    cursor: not-allowed;
    border-color: #999;
    background-image: linear-gradient(bottom, rgb(200,200,200) 0%, rgb(150,150,150) 100%);
    background-image: -o-linear-gradient(bottom, rgb(200,200,200) 0%, rgb(150,150,150) 100%);
    background-image: -moz-linear-gradient(bottom, rgb(200,200,200) 0%, rgb(150,150,150) 100%);
    background-image: -webkit-linear-gradient(bottom, rgb(200,200,200) 0%, rgb(150,150,150) 100%);
    background-image: -ms-linear-gradient(bottom, rgb(200,200,200) 0%, rgb(150,150,150) 100%);
}
.link-button {
    display: inline-block;
    padding: 6px 0;
}
.spinner {
    float: right;
    margin: 8px 10px 0 0;
}


/******************************************************************************
    modifier: inline-form
*/
.inline-form label {
    display: inline;
    margin-right: 4px;
}
