#flash-messages {
    margin: 0;
    padding: 0;
}
#flash-messages li {
    list-style: none;
    padding: 8px 20px;
    margin: 0 10px;
    box-shadow: 1px 1px 4px rgba(0,0,0,0.2);
    font-weight: bold;
    text-shadow: 0 -1px 0 rgba(0,0,0,0.3);
    color: #FFF;
}
#flash-messages li:first-child {
    margin-top: 10px;
    -webkit-border-top-left-radius: 4px;
    -webkit-border-top-right-radius: 4px;
    -moz-border-radius-topleft: 4px;
    -moz-border-radius-topright: 4px;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
}
#flash-messages li:last-child {
    margin-bottom: 5px;
    -webkit-border-bottom-right-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px;
}
#flash-messages li.info {
    background-color: #19B6EE;
}
#flash-messages li.success {
    background-color: #38B44A;
}
#flash-messages li.warning {
    background-color: #ECA918;
}
#flash-messages li.error {
    background-color: #DF382C;
}
