{% extends "base-modal.html" %}
{% block title %}{{ title }}{% endblock %}
{% block content %}
    {% from "forms/macros.html" import render_field %}
    <form method="post" action="{{ request.path }}" class="form">
        {{ form.csrf_token }}
        <p>
            Continuing will irreversably destroy user '{{ username }}'.<br />
            Are you sure you want to continue?
        </p>
        <ul>
        {% for field in form.visible_fields %}
        {{ render_field(field) }}
        {% endfor %}
        </ul>
        {% if parent %}
        <a class="link-button" href="{{ parent }}">Cancel</a>
        {% endif %}
        <input class="right" type="submit" value="{{ action }}" />
    </form>
{% endblock %}
